def SYSTEM_EV_HEADPHONES_INSERTED(): pass

def SYSTEM_EV_HEADPHONES_REMOVED(): pass

def SYSTEM_EV_SOUND_VOLUME_CHANGED(): pass

def SYSTEM_EV_PHONE_RINGING(): pass

def SYSTEM_EV_PHONE_ANSWERING(): pass

def SYSTEM_EV_PHONE_DIALING(): pass

def SYSTEM_EV_PHONE_HANGUP(): pass

def SYSTEM_EV_NORMAL_MODE(): pass

def SYSTEM_EV_OFFLINE_MODE(): pass

def POLICY_EV_FMRADIO_DISALLOWED(): pass

def POLICY_EV_FMRADIO_ALLOWED(): pass

